@@ -11,6 +11,10 @@ import pgcrypto
 import logging
 import schedule
 import time
+from datetime import datetime
+import logging
+import sys
+import os
 
 
 cached_database_metas = {}
@@ -213,6 +217,9 @@ class StateWatcher(models.Model):
     )
     last_state = models.CharField(max_length=1073741824, editable=False)
 
+    def __str__(self):
+        return self.name
+
     def get_state(self):
         """Rerun the query to get current state
         """
@@ -234,6 +241,14 @@ class StateWatcher(models.Model):
         Returns:
             dict: dictionary with zero of more of the
             following keys
+                - old_dict: Containes a dict where each key is
+                    an id for a record and each value is a
+                    record. It contains information based on
+                    the old_state provided
+                - new_dict: Containes a dict where each key is
+                    an id for a record and each value is a
+                    record. It contains information based on
+                    the new_state provided
                 - added: Contains a list of records added
                 - removed: Contains a list of records removed
                 - modified: Contains a dict having keys being
@@ -287,19 +302,38 @@ class StateWatcher(models.Model):
         return results
 
     def update(self):
-        """This function should be falled periodically as per self.interval
+        """This function should be called periodically as per self.interval
         """
-        new_state = self.get_state()
-        old_state = json.loads(self.last_state) if self.last_state else None
-        diff = self.comp(old_state, new_state)
-        self.last_state = json.dumps(new_state)
-        self.save()
-        return diff
+        try:
+            new_state = self.get_state()
+            old_state = \
+                json.loads(self.last_state) if self.last_state else None
+            diff = self.comp(old_state, new_state)
+            self.last_state = json.dumps(new_state)
+            self.save()
+            return diff
+        except Exception as e:
+            ct = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            logging.warning(
+                f"{ct} StateWatcher({self}).update failed with exception: \n"
+                f"{exc_type} in {fname} at {exc_tb.tb_lineno}"
+            )
 
     def refresh(self):
         changes = self.update()
         if changes:
-            ActionsManager.actions_map[self.target](changes)
+            try:
+                ActionsManager.actions_map[self.target](changes)
+            except Exception as e:
+                ct = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+                exc_type, exc_obj, exc_tb = sys.exc_info()
+                fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+                logging.warning(
+                    f"{ct} StateWatcher({self}).refresh failed with "
+                    f"exception: \n{exc_type} in {fname} at {exc_tb.tb_lineno}"
+                )
 
     @classmethod
     def start(cls):
